@@ -4,11 +4,13 @@ from collections.abc import Coroutine
 from django.utils.translation import get_language, override
 from rest_framework import status
 from rest_framework.response import Response
+from rest_framework.schemas.openapi import AutoSchema
 from rest_framework.serializers import BaseSerializer
 from rest_framework.views import APIView
 
 from .exceptions import NextLogicBlock
 from .inference import serializer_from_callable
+from .schema import PipelineSchemaMixin
 from .typing import (
     Any,
     DataDict,
@@ -35,6 +37,8 @@ class BaseAPIView(APIView):
     pipelines: PipelinesDict = {}
     """Dictionary describing the HTTP method pipelines."""
 
+    schema = type("Schema", (PipelineSchemaMixin, AutoSchema), {})()
+
     async def process_request(self, data: DataDict, lang: str = None) -> Response:
         """Process request in a pipeline-fashion."""
         if lang is None:
@@ -119,7 +123,8 @@ class BaseAPIView(APIView):
         kwargs["serializer_class"] = self.get_serializer_class(output=kwargs.pop("output", False))
         return self.initialize_serializer(*args, **kwargs)
 
-    def initialize_serializer(self, serializer_class: SerializerType, *args: Any, **kwargs: Any) -> BaseSerializer:
+    def initialize_serializer(self, *args: Any, **kwargs: Any) -> BaseSerializer:
+        serializer_class: SerializerType = kwargs.pop("serializer_class")
         kwargs.setdefault("context", self.get_serializer_context())
         kwargs.setdefault("many", getattr(serializer_class, "many", False))
         if kwargs.get("data", sentinel) is None:
